article

package
v0.2.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 25, 2026 License: MIT Imports: 20 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func New

func New(nodes ...node.Node) *element

New Creates a new article element with optional child nodes Example: article.New() Renders: <article></article>

func RawText

func RawText(str string) *element

RawText Creates a new article element with raw text content as unescaped HTML using text.RawText. Example: article.RawText("This is <em>article</em>") Renders: <article>This is <em>article</em></article>

func RawTextf

func RawTextf(format string, args ...any) *element

RawTextf Creates a new article element with formatted raw text content as unescaped HTML using text.RawTextf. Example: article.RawTextf("Hello <em>%s</em>", "World") Renders: <article>Hello <em>World</em></article>

func Static

func Static(str string) *element

Static Creates a new article element with static text content. Example: article.Static("Hello World") Renders: <article>Hello World</article>

func Text

func Text(str string) *element

Text Creates a new article element with text content Example: article.Text("This is an article") Renders: <article>This is an article</article>

func Textf

func Textf(format string, args ...any) *element

Textf Creates a new article element with formatted text content using text.Textf. Example: article.Textf("Hello %s", "World") Renders: <article>Hello World</article>

Types

type Element

type Element = element

Element is an exported alias for the private element type

Jump to