b

package
v0.2.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 25, 2026 License: MIT Imports: 20 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func New

func New(nodes ...node.Node) *element

New Creates a new b element with the given child nodes. Example: b.New(text.Text("This text is important.")) Renders: <b>This text is important.</b>

func RawText

func RawText(str string) *element

RawText Creates a new b element with raw text content as unescaped HTML. Example: b.RawText("<em>This text</em> is important.") Renders: <b><em>This text</em> is important.</b>

func RawTextf

func RawTextf(format string, args ...any) *element

RawTextf Creates a new b element with formatted raw text content as unescaped HTML using text.RawTextf. Example: b.RawTextf("Hello <em>%s</em>", "World") Renders: <b>Hello <em>World</em></b>

func Static

func Static(str string) *element

Static Creates a new b element with static text content. Example: b.Static("Hello World") Renders: <b>Hello World</b>

func Text

func Text(str string) *element

Text Creates a new b element with text content (HTML-encoded). Example: b.Text("<em>This text</em> is important.") Renders: <b>&lt;em&gt;This text&lt;/em&gt; is important.</b>

func Textf

func Textf(format string, args ...any) *element

Textf Creates a new b element with formatted text content using text.Textf. Example: b.Textf("Hello %s", "World") Renders: <b>Hello World</b>

Types

type Element

type Element = element

Element is an exported alias for the private element type

Jump to