package
Version:
v0.2.0
Opens a new window with list of versions in this module.
Published: Feb 25, 2026
License: MIT
Opens a new window with license information.
Imports: 19
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
New Creates a new base element without any initial attributes.
Example: base.New().Href("/docs/")
Renders: <base href="/docs/" />
func URL(href string) *element
URL Creates a base element with the specified base URL.
Example: base.URL("/docs/")
Renders: <base href="/docs/" />
Element is an exported alias for the private element type
Source Files
¶
Click to show internal directories.
Click to hide internal directories.