figure

package
v0.2.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 25, 2026 License: MIT Imports: 20 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func New

func New(nodes ...node.Node) *element

New Creates a new figure element with the given child nodes. Example: figure.New(img.New().Src("elephant.jpg"), figcaption.New(text.Text("An elephant at sunset"))) Renders: <figure><img src="elephant.jpg" /><figcaption>An elephant at sunset</figcaption></figure>

Types

type Element

type Element = element

Element is an exported alias for the private element type

Jump to