Documentation
¶
Overview ¶
Package mark provides constructors and methods for the HTML <mark> element.
The <mark> HTML element represents text which is marked or highlighted for reference or notation purposes due to the marked passage's relevance in the enclosing context.
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ( TagOpen = []byte("<mark") TagClose = []byte("</mark>") )
Byte constants for HTML rendering.
Functions ¶
func New ¶
New creates a new mark element with the given child nodes. Example: mark.New(text.Text("highlighted text")) Renders: <mark>highlighted text</mark>
func RawText ¶
func RawText(str string) *element
RawText creates a new mark element with raw text content. Uses text.RawText which is not HTML-escaped. Example: mark.RawText("<strong>important</strong> result") Renders: <mark><strong>important</strong> result</mark>
func RawTextf ¶
RawTextf creates a new mark element with formatted raw text content. Uses text.RawTextf which is not HTML-escaped. Example: mark.RawTextf("<b>%s</b>", term) Renders: <mark><b>HTML</b></mark>
func Static ¶
func Static(str string) *element
Static creates a new mark element with static text content. Uses text.Static which is not HTML-escaped and is JIT-optimisable. Example: mark.Static("important") Renders: <mark>important</mark>