math

package
v0.2.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 25, 2026 License: MIT Imports: 20 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func New

func New(nodes ...node.Node) *element

New Creates a new math element with optional child nodes. Example: math.New() Renders: <math></math>

func RawText

func RawText(str string) *element

RawText Creates a new math element with raw text content. Example: math.RawText("x + y") Renders: <math>x + y</math>

func RawTextf

func RawTextf(format string, args ...any) *element

RawTextf Creates a new math element with formatted raw text content as unescaped HTML. Example: math.RawTextf("<mi>%s</mi> + <mi>%s</mi>", "x", "y") Renders: <math><mi>x</mi> + <mi>y</mi></math>

func Static

func Static(str string) *element

Static Creates a new math element with static text content. Example: math.Static("Hello World") Renders: <math>Hello World</math>

func Text

func Text(str string) *element

Text Creates a new math element with text content. Example: math.Text("x + y") Renders: <math>x + y</math>

func Textf

func Textf(format string, args ...any) *element

Textf Creates a new math element with formatted text content (HTML-encoded). Example: math.Textf("%s + %s", "x", "y") Renders: <math>x + y</math>

Types

type Element

type Element = element

Element is an exported alias for the private element type

Jump to