output

package
v0.3.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 5, 2026 License: MIT Imports: 21 Imported by: 0

Documentation

Overview

Package output provides constructors and methods for the HTML <output> element.

The <output> HTML element is a container element into which a site or app can inject the results of a calculation or the outcome of a user action.

Index

Constants

This section is empty.

Variables

var (
	TagOpen  = []byte("<output")
	TagClose = []byte("</output>")

	AttrFor  = []byte(" for=\"")
	AttrForm = []byte(" form=\"")
	AttrName = []byte(" name=\"")
)

Byte constants for HTML rendering.

Functions

func New

func New(nodes ...node.Node) *element

New creates a new output element with optional child nodes Example: output.New() Renders: <output></output>

func RawText

func RawText(content string) *element

RawText creates a new output element with raw text content. Uses text.RawText which is not HTML-escaped. Example: output.RawText("<strong>100</strong>") Renders: <output><strong>100</strong></output>

func RawTextf

func RawTextf(format string, args ...any) *element

RawTextf creates a new output element with formatted raw text content. Uses text.RawTextf which is not HTML-escaped. Example: output.RawTextf("<strong>%d</strong>", total) Renders: <output><strong>10</strong></output>

func Static

func Static(content string) *element

Static creates a new output element with static text content. Uses text.Static which is not HTML-escaped and is JIT-optimisable. Example: output.Static("0") Renders: <output>0</output>

func Text

func Text(content string) *element

Text creates a new output element with text content. Uses text.Text which HTML-escapes the output. Example: output.Text("Result: 42") Renders: <output>Result: 42</output>

func Textf

func Textf(format string, args ...any) *element

Textf creates a new output element with formatted text content. Uses text.Textf which HTML-escapes the output. Example: output.Textf("Result: %d", total) Renders: <output>Result: 10</output>

Types

type Element

type Element = element

Element is an exported alias for the private element type

Jump to