ruby

package
v0.2.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 25, 2026 License: MIT Imports: 20 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func New

func New(nodes ...node.Node) *element

New Creates a new ruby element with optional child nodes Example: ruby.New(text.Text("漢字")) Renders: <ruby>漢字</ruby>

func RawText

func RawText(content string) *element

RawText Creates a new ruby element with raw text content Example: ruby.RawText("漢<rt>かん</rt>") Renders: <ruby>漢<rt>かん</rt></ruby>

func RawTextf

func RawTextf(format string, args ...any) *element

RawTextf Creates a new ruby element with formatted raw text content as unescaped HTML Example: ruby.RawTextf("%s<rt>%s</rt>", "漢", "かん") Renders: <ruby>漢<rt>かん</rt></ruby>

func Static

func Static(content string) *element

Static Creates a new ruby element with static text content Example: ruby.Static("日本") Renders: <ruby>日本</ruby>

func Text

func Text(content string) *element

Text Creates a new ruby element with text content Example: ruby.Text("東京") Renders: <ruby>東京</ruby>

func Textf

func Textf(format string, args ...any) *element

Textf Creates a new ruby element with formatted text content (HTML-encoded) Example: ruby.Textf("Chapter %d", 1) Renders: <ruby>Chapter 1</ruby>

Types

type Element

type Element = element

Element is an exported alias for the private element type

Jump to