section

package
v0.2.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 25, 2026 License: MIT Imports: 20 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func New

func New(nodes ...node.Node) *element

New Creates a new section element with optional child nodes Example: section.New() Renders: <section></section>

func RawText

func RawText(content string) *element

RawText Creates a new section element with raw text content as unescaped HTML Example: section.RawText("<h2>Title</h2>") Renders: <section><h2>Title</h2></section>

func RawTextf

func RawTextf(format string, args ...any) *element

RawTextf Creates a new section element with formatted raw text content as unescaped HTML using text.RawTextf Example: section.RawTextf("<h2>%s</h2>", "Title") Renders: <section><h2>Title</h2></section>

func Static

func Static(content string) *element

Static Creates a new section element with static text content Example: section.Static("Content") Renders: <section>Content</section>

func Text

func Text(content string) *element

Text Creates a new section element with text content Example: section.Text("Section content") Renders: <section>Section content</section>

func Textf

func Textf(format string, args ...any) *element

Textf Creates a new section element with formatted text content using text.Textf Example: section.Textf("Section %d", 1) Renders: <section>Section 1</section>

Types

type Element

type Element = element

Element is an exported alias for the private element type

Jump to