Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func New ¶
New Creates a new small element with the given child nodes. Example: small.New(text.Text("© 2024 Company Name")) Renders: <small>© 2024 Company Name</small>
func RawText ¶
func RawText(str string) *element
RawText Creates a new small element with raw text content as unescaped HTML. Example: small.RawText("© 2024 <em>Company</em>") Renders: <small>© 2024 <em>Company</em></small>
func RawTextf ¶
RawTextf Creates a new small element with formatted raw text content as unescaped HTML using text.RawTextf. Example: small.RawTextf("© %d <em>%s</em>", 2024, "Company") Renders: <small>© 2024 <em>Company</em></small>
func Static ¶
func Static(str string) *element
Static Creates a new small element with static text content. Example: small.Static("Hello World") Renders: <small>Hello World</small>