span

package
v0.2.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 25, 2026 License: MIT Imports: 20 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func New

func New(nodes ...node.Node) *element

New Creates a new span element with optional child nodes. Example: span.New() Renders: <span></span>

func RawText

func RawText(content string) *element

RawText Creates a new span element with raw text content as unescaped HTML. Example: span.RawText("Hello <b>World</b>") Renders: <span>Hello <b>World</b></span>

func RawTextf

func RawTextf(format string, args ...any) *element

RawTextf Creates a new span element with formatted raw text content as unescaped HTML using text.RawTextf. Example: span.RawTextf("Hello <b>%s</b>", "World") Renders: <span>Hello <b>World</b></span>

func Static

func Static(content string) *element

Static Creates a new span element with static text content. Example: span.Static("Hello World") Renders: <span>Hello World</span>

func Text

func Text(content string) *element

Text Creates a new span element with text content (HTML-encoded). Example: span.Text("<b>Hello</b> World") Renders: <span>&lt;b&gt;Hello&lt;/b&gt; World</span>

func Textf

func Textf(format string, args ...any) *element

Textf Creates a new span element with formatted text content using text.Textf. Example: span.Textf("Hello %s", "World") Renders: <span>Hello World</span>

Types

type Element

type Element = element

Element is an exported alias for the private element type

Jump to