Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func New ¶
New Creates a new summary element with optional child nodes. Example: summary.New() Renders: <summary></summary>
func RawText ¶
func RawText(content string) *element
RawText Creates a new summary element with raw text content as unescaped HTML. Example: summary.RawText("<strong>Click</strong> to expand") Renders: <summary><strong>Click</strong> to expand</summary>
func RawTextf ¶
RawTextf Creates a new summary element with formatted raw text content as unescaped HTML using text.RawTextf. Example: summary.RawTextf("<strong>%s</strong> to %s", "Click", "expand") Renders: <summary><strong>Click</strong> to expand</summary>
func Static ¶
func Static(content string) *element
Static Creates a new summary element with static text content. Example: summary.Static("Hello World") Renders: <summary>Hello World</summary>