sup

package
v0.2.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 25, 2026 License: MIT Imports: 20 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func New

func New(nodes ...node.Node) *element

New Creates a new sup element with the given child nodes. Example: sup.New(text.Text("2")) Renders: <sup>2</sup>

func RawText

func RawText(content string) *element

RawText Creates a new sup element with raw text content as unescaped HTML. Example: sup.RawText("<em>2</em>") Renders: <sup><em>2</em></sup>

func RawTextf

func RawTextf(format string, args ...any) *element

RawTextf Creates a new sup element with formatted raw text content as unescaped HTML using text.RawTextf. Example: sup.RawTextf("<em>%d</em>", 2) Renders: <sup><em>2</em></sup>

func Static

func Static(content string) *element

Static Creates a new sup element with static text content. Example: sup.Static("Hello World") Renders: <sup>Hello World</sup>

func Text

func Text(content string) *element

Text Creates a new sup element with text content (HTML-encoded). Example: sup.Text("<em>2</em>") Renders: <sup>&lt;em&gt;2&lt;/em&gt;</sup>

func Textf

func Textf(format string, args ...any) *element

Textf Creates a new sup element with formatted text content using text.Textf. Example: sup.Textf("%d", 2) Renders: <sup>2</sup>

Types

type Element

type Element = element

Element is an exported alias for the private element type

Jump to