Documentation
¶
Index ¶
- func Col(content string) *element
- func ColGroup(content string) *element
- func New(nodes ...node.Node) *element
- func RawText(content string) *element
- func RawTextf(format string, args ...any) *element
- func Row(content string) *element
- func RowGroup(content string) *element
- func Static(content string) *element
- func Text(content string) *element
- func Textf(format string, args ...any) *element
- type Element
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Col ¶
func Col(content string) *element
Col Creates a column header with scope="col" Example: th.Col("Name") Renders: <th scope="col">Name</th>
func ColGroup ¶
func ColGroup(content string) *element
ColGroup Creates a column group header with scope="colgroup" Example: th.ColGroup("Sales Data") Renders: <th scope="colgroup">Sales Data</th>
func New ¶
New Creates a new th element with optional child nodes. Example: th.New() Renders: <th></th>
func RawText ¶
func RawText(content string) *element
RawText Creates a new th element with raw text content as unescaped HTML. Example: th.RawText("<strong>Name</strong>") Renders: <th><strong>Name</strong></th>
func RawTextf ¶
RawTextf Creates a new th element with formatted raw text content as unescaped HTML using text.RawTextf. Example: th.RawTextf("<strong>%s</strong>", "Name") Renders: <th><strong>Name</strong></th>
func Row ¶
func Row(content string) *element
Row Creates a row header with scope="row" Example: th.Row("Total") Renders: <th scope="row">Total</th>
func RowGroup ¶
func RowGroup(content string) *element
RowGroup Creates a row group header with scope="rowgroup" Example: th.RowGroup("Q1 Results") Renders: <th scope="rowgroup">Q1 Results</th>
func Static ¶
func Static(content string) *element
Static Creates a new th element with static text content. Example: th.Static("Hello World") Renders: <th>Hello World</th>