Documentation
¶
Overview ¶
Package tr provides constructors and methods for the HTML <tr> element.
The <tr> HTML element defines a row of cells in a table. The row's cells can then be established using a mix of <td> (data cell) and <th> (header cell) elements.
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ( TagOpen = []byte("<tr") TagClose = []byte("</tr>") AttrAlign = []byte(" align=\"") AttrBgColor = []byte(" bgcolor=\"") AttrChar = []byte(" char=\"") AttrCharOff = []byte(" charoff=\"") AttrVAlign = []byte(" valign=\"") )
Byte constants for HTML rendering.
Functions ¶
func Cells ¶ added in v0.3.0
Cells creates a table row from td data cells, enforcing correct nesting at compile time. Example: tr.Cells(td.Text("a"), td.Text("b")) Renders: <tr><td>a</td><td>b</td></tr>
Types ¶
Click to show internal directories.
Click to hide internal directories.