variable

package
v0.2.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 25, 2026 License: MIT Imports: 20 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func New

func New(nodes ...node.Node) *element

New Creates a new var element with optional child nodes. Example: variable.New() Renders: <var></var>

func RawText

func RawText(content string) *element

RawText Creates a new var element with raw text content as unescaped HTML. Example: variable.RawText("<em>x</em>") Renders: <var><em>x</em></var>

func RawTextf

func RawTextf(format string, args ...any) *element

RawTextf Creates a new var element with formatted raw text content as unescaped HTML using text.RawTextf. Example: variable.RawTextf("<em>%s</em>", "x") Renders: <var><em>x</em></var>

func Static

func Static(content string) *element

Static Creates a new var element with static text content. Example: variable.Static("Hello World") Renders: <var>Hello World</var>

func Text

func Text(content string) *element

Text Creates a new var element with text content. Example: variable.Text("x") Renders: <var>x</var>

func Textf

func Textf(format string, args ...any) *element

Textf Creates a new var element with formatted text content using text.Textf. Example: variable.Textf("%s", "x") Renders: <var>x</var>

Types

type Element

type Element = element

Element is an exported alias for the private element type

Jump to