Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func New ¶
New Creates a new article element with optional child nodes Example: article.New() Renders: <article></article>
func RawText ¶
func RawText(str string) *element
RawText Creates a new article element with raw text content as unescaped HTML using text.RawText. Example: article.RawText("This is <em>article</em>") Renders: <article>This is <em>article</em></article>
func RawTextf ¶
RawTextf Creates a new article element with formatted raw text content as unescaped HTML using text.RawTextf. Example: article.RawTextf("Hello <em>%s</em>", "World") Renders: <article>Hello <em>World</em></article>
func Static ¶
func Static(str string) *element
Static Creates a new article element with static text content. Example: article.Static("Hello World") Renders: <article>Hello World</article>