Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func New ¶
New Creates a new b element with the given child nodes. Example: b.New(text.Text("This text is important.")) Renders: <b>This text is important.</b>
func RawText ¶
func RawText(str string) *element
RawText Creates a new b element with raw text content as unescaped HTML. Example: b.RawText("<em>This text</em> is important.") Renders: <b><em>This text</em> is important.</b>
func RawTextf ¶
RawTextf Creates a new b element with formatted raw text content as unescaped HTML using text.RawTextf. Example: b.RawTextf("Hello <em>%s</em>", "World") Renders: <b>Hello <em>World</em></b>
func Static ¶
func Static(str string) *element
Static Creates a new b element with static text content. Example: b.Static("Hello World") Renders: <b>Hello World</b>
Types ¶
Click to show internal directories.
Click to hide internal directories.