Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func New ¶
New Creates a new div element with child nodes. Example: div.New(p.New(text.Text("Any kind of content here."))) Renders: <div><p>Any kind of content here.</p></div>
func RawText ¶
func RawText(str string) *element
RawText Creates a new div element with raw text content as unescaped HTML. Example: div.RawText("<b>This is a div</b> with raw text content.") Renders: <div><b>This is a div</b> with raw text content.</div>
func RawTextf ¶
RawTextf Creates a new div element with formatted raw text content as unescaped HTML using text.RawTextf. Example: div.RawTextf("Hello <em>%s</em>", "World") Renders: <div>Hello <em>World</em></div>
func Static ¶
func Static(str string) *element
Static Creates a new div element with static text content. Example: div.Static("Hello World") Renders: <div>Hello World</div>