Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Audio ¶
Audio Creates an embed element for audio content Example: embed.Audio("song.mp3", 320, 50) Renders: <embed src="song.mp3" type="audio/mpeg" width="320" height="50" />
func Flash ¶
Flash Creates an embed element for Flash content (legacy) Example: embed.Flash("animation.swf", 640, 480) Renders: <embed src="animation.swf" type="application/x-shockwave-flash" width="640" height="480" />
func New ¶
func New() *element
New Creates a new embed element without any initial attributes. Example: embed.New() Renders: <embed />
Types ¶
Click to show internal directories.
Click to hide internal directories.