Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func New ¶
New Creates a new math element with optional child nodes. Example: math.New() Renders: <math></math>
func RawText ¶
func RawText(str string) *element
RawText Creates a new math element with raw text content. Example: math.RawText("x + y") Renders: <math>x + y</math>
func RawTextf ¶
RawTextf Creates a new math element with formatted raw text content as unescaped HTML. Example: math.RawTextf("<mi>%s</mi> + <mi>%s</mi>", "x", "y") Renders: <math><mi>x</mi> + <mi>y</mi></math>
func Static ¶
func Static(str string) *element
Static Creates a new math element with static text content. Example: math.Static("Hello World") Renders: <math>Hello World</math>
Types ¶
Click to show internal directories.
Click to hide internal directories.