Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func New ¶
New Creates a new ruby element with optional child nodes Example: ruby.New(text.Text("漢字")) Renders: <ruby>漢字</ruby>
func RawText ¶
func RawText(content string) *element
RawText Creates a new ruby element with raw text content Example: ruby.RawText("漢<rt>かん</rt>") Renders: <ruby>漢<rt>かん</rt></ruby>
func RawTextf ¶
RawTextf Creates a new ruby element with formatted raw text content as unescaped HTML Example: ruby.RawTextf("%s<rt>%s</rt>", "漢", "かん") Renders: <ruby>漢<rt>かん</rt></ruby>
func Static ¶
func Static(content string) *element
Static Creates a new ruby element with static text content Example: ruby.Static("日本") Renders: <ruby>日本</ruby>
Types ¶
Click to show internal directories.
Click to hide internal directories.