Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func New ¶
New Creates a new section element with optional child nodes Example: section.New() Renders: <section></section>
func RawText ¶
func RawText(content string) *element
RawText Creates a new section element with raw text content as unescaped HTML Example: section.RawText("<h2>Title</h2>") Renders: <section><h2>Title</h2></section>
func RawTextf ¶
RawTextf Creates a new section element with formatted raw text content as unescaped HTML using text.RawTextf Example: section.RawTextf("<h2>%s</h2>", "Title") Renders: <section><h2>Title</h2></section>
func Static ¶
func Static(content string) *element
Static Creates a new section element with static text content Example: section.Static("Content") Renders: <section>Content</section>
Types ¶
Click to show internal directories.
Click to hide internal directories.