small

package
v0.2.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 25, 2026 License: MIT Imports: 20 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func New

func New(nodes ...node.Node) *element

New Creates a new small element with the given child nodes. Example: small.New(text.Text("© 2024 Company Name")) Renders: <small>© 2024 Company Name</small>

func RawText

func RawText(str string) *element

RawText Creates a new small element with raw text content as unescaped HTML. Example: small.RawText("© 2024 <em>Company</em>") Renders: <small>© 2024 <em>Company</em></small>

func RawTextf

func RawTextf(format string, args ...any) *element

RawTextf Creates a new small element with formatted raw text content as unescaped HTML using text.RawTextf. Example: small.RawTextf("© %d <em>%s</em>", 2024, "Company") Renders: <small>© 2024 <em>Company</em></small>

func Static

func Static(str string) *element

Static Creates a new small element with static text content. Example: small.Static("Hello World") Renders: <small>Hello World</small>

func Text

func Text(str string) *element

Text Creates a new small element with text content (HTML-encoded). Example: small.Text("© 2024 <em>Company</em>") Renders: <small>© 2024 &lt;em&gt;Company&lt;/em&gt;</small>

func Textf

func Textf(format string, args ...any) *element

Textf Creates a new small element with formatted text content using text.Textf. Example: small.Textf("© %d %s", 2024, "Company") Renders: <small>© 2024 Company</small>

Types

type Element

type Element = element

Element is an exported alias for the private element type

Jump to