Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func New ¶
New Creates a new span element with optional child nodes. Example: span.New() Renders: <span></span>
func RawText ¶
func RawText(content string) *element
RawText Creates a new span element with raw text content as unescaped HTML. Example: span.RawText("Hello <b>World</b>") Renders: <span>Hello <b>World</b></span>
func RawTextf ¶
RawTextf Creates a new span element with formatted raw text content as unescaped HTML using text.RawTextf. Example: span.RawTextf("Hello <b>%s</b>", "World") Renders: <span>Hello <b>World</b></span>
func Static ¶
func Static(content string) *element
Static Creates a new span element with static text content. Example: span.Static("Hello World") Renders: <span>Hello World</span>
Types ¶
Click to show internal directories.
Click to hide internal directories.