Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func New ¶
New Creates a new sup element with the given child nodes. Example: sup.New(text.Text("2")) Renders: <sup>2</sup>
func RawText ¶
func RawText(content string) *element
RawText Creates a new sup element with raw text content as unescaped HTML. Example: sup.RawText("<em>2</em>") Renders: <sup><em>2</em></sup>
func RawTextf ¶
RawTextf Creates a new sup element with formatted raw text content as unescaped HTML using text.RawTextf. Example: sup.RawTextf("<em>%d</em>", 2) Renders: <sup><em>2</em></sup>
func Static ¶
func Static(content string) *element
Static Creates a new sup element with static text content. Example: sup.Static("Hello World") Renders: <sup>Hello World</sup>
Types ¶
Click to show internal directories.
Click to hide internal directories.