Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func New ¶
New Creates a new var element with optional child nodes. Example: variable.New() Renders: <var></var>
func RawText ¶
func RawText(content string) *element
RawText Creates a new var element with raw text content as unescaped HTML. Example: variable.RawText("<em>x</em>") Renders: <var><em>x</em></var>
func RawTextf ¶
RawTextf Creates a new var element with formatted raw text content as unescaped HTML using text.RawTextf. Example: variable.RawTextf("<em>%s</em>", "x") Renders: <var><em>x</em></var>
func Static ¶
func Static(content string) *element
Static Creates a new var element with static text content. Example: variable.Static("Hello World") Renders: <var>Hello World</var>
Types ¶
Click to show internal directories.
Click to hide internal directories.